@@ -100,7 +100,9 @@ async def accumulate(
                 else await anext(item_iter)
             )
         except StopAsyncIteration:
-            raise TypeError("accumulate() of empty sequence with no initial value")
+            raise TypeError(
+                "accumulate() of empty sequence with no initial value"
+            ) from None
         function = _awaitify(function)
         yield value
         async for head in item_iter:
